@@ -1,11 +1,11 @@
 SET search_path TO public;
+SET client_min_messages TO log;
 
 EXPLAIN (COSTS false) SELECT * FROM t1, t2 WHERE t1.id = t2.id;
 EXPLAIN (COSTS false) SELECT * FROM t1, t2 WHERE t1.val = t2.val;
 
 LOAD 'pg_hint_plan';
 SET pg_hint_plan.debug_print TO on;
-SET client_min_messages TO LOG;
 
 EXPLAIN (COSTS false) SELECT * FROM t1, t2 WHERE t1.id = t2.id;
 EXPLAIN (COSTS false) SELECT * FROM t1, t2 WHERE t1.val = t2.val;
@@ -836,137 +836,93 @@ VACUUM ANALYZE hint_plan.hints;
 
 -- plpgsql test
 EXPLAIN (COSTS false) SELECT id FROM t1 WHERE t1.id = 1;
-
--- static function
-CREATE FUNCTION testfunc() RETURNS RECORD AS $$
+DO LANGUAGE plpgsql $$
 DECLARE
-  ret record;
+    id integer;
 BEGIN
-  SELECT /*+ SeqScan(t1) */ * INTO ret FROM t1 LIMIT 1;
-  RETURN ret;
+	SELECT /*+SeqScan(t1)*/ t1.id INTO id FROM t1 WHERE t1.id = 1;
+	RETURN;
 END;
-$$ LANGUAGE plpgsql;
-SELECT testfunc();
-
--- dynamic function
-DROP FUNCTION testfunc();
-CREATE FUNCTION testfunc() RETURNS void AS $$
-BEGIN
-  EXECUTE format('/*+ SeqScan(t1) */ SELECT * FROM t1');
-END;
-$$ LANGUAGE plpgsql;
-SELECT testfunc();
-
--- This should not use SeqScan(t1)
-/*+ IndexScan(t1) */ SELECT * from t1 LIMIT 1;
-
--- Perform
-DROP FUNCTION testfunc();
-CREATE FUNCTION testfunc() RETURNS void AS $$
-BEGIN
-  PERFORM  1, /*+ SeqScan(t1) */ * from t1;
-END;
-$$ LANGUAGE plpgsql;
-SELECT testfunc();
-
--- FOR loop
-DROP FUNCTION testfunc();
-CREATE FUNCTION testfunc() RETURNS int AS $$
-DECLARE
-  sum int;
-  v int;
-BEGIN
-  sum := 0;
-  FOR v IN SELECT /*+ SeqScan(t1) */ v FROM t1 ORDER BY id LOOP
-    sum := sum + v;
-  END LOOP;
-  RETURN v;
-END;
-$$ LANGUAGE plpgsql;
-SELECT testfunc();
-
--- Dynamic FOR loop
-DROP FUNCTION testfunc();
-CREATE FUNCTION testfunc() RETURNS int AS $$
-DECLARE
-  sum int;
-  v int;
-  i   int;
-BEGIN
-  sum := 0;
-  FOR v IN EXECUTE 'SELECT /*+ SeqScan(t1) */ val FROM t1 ORDER BY id' LOOP
-    sum := sum + v;
-  END LOOP;
-  RETURN v;
-END;
-$$ LANGUAGE plpgsql;
-SELECT testfunc();
-
--- Cursor FOR loop
-DROP FUNCTION testfunc();
-CREATE FUNCTION testfunc() RETURNS int AS $$
-DECLARE
-  ref CURSOR FOR SELECT /*+ SeqScan(t1) */ * FROM t1 ORDER BY id;
-  rec record;
-  sum int := 0;
-BEGIN
-  FOR rec IN ref LOOP
-    sum := sum + rec.val;
-  END LOOP;
-  RETURN sum;
-END;
-$$ LANGUAGE plpgsql;
-SELECT testfunc();
-
--- RETURN QUERY
-DROP FUNCTION testfunc();
-CREATE FUNCTION testfunc() RETURNS SETOF t1 AS $$
-BEGIN
-  RETURN QUERY SELECT /*+ SeqScan(t1) */ * FROM t1 ORDER BY id;
-END;
-$$ LANGUAGE plpgsql;
-SELECT * FROM testfunc() LIMIT 1;
-
--- Test for error exit from inner SQL statement.
-DROP FUNCTION testfunc();
-CREATE FUNCTION testfunc() RETURNS SETOF t1 AS $$
-BEGIN
-  RETURN QUERY SELECT /*+ SeqScan(t1) */ * FROM ttx ORDER BY id;
-END;
-$$ LANGUAGE plpgsql;
-SELECT * FROM testfunc() LIMIT 1;
-
--- this should not use SeqScan(t1) hint.
-/*+ IndexScan(t1) */ SELECT * from t1 LIMIT 1;
-
-DROP FUNCTION testfunc();
+$$;
 DROP EXTENSION pg_hint_plan;
 
 --
 -- Rows hint tests
 --
+-- Explain result includes "Planning time" if COSTS is enabled, but
+-- this test needs it enabled for get rows count. So do tests via psql
+-- and grep -v the mutable line.
+
 -- value types
+\o results/pg_hint_plan.tmpout
 EXPLAIN SELECT * FROM t1 JOIN t2 ON (t1.id = t2.id);
+\o
+\! sql/maskout.sh results/pg_hint_plan.tmpout
+
+\o results/pg_hint_plan.tmpout
 /*+ Rows(t1 t2 #99) */
 EXPLAIN SELECT * FROM t1 JOIN t2 ON (t1.id = t2.id);
+\o
+\! sql/maskout.sh results/pg_hint_plan.tmpout
+
+\o results/pg_hint_plan.tmpout
 /*+ Rows(t1 t2 +99) */
 EXPLAIN SELECT * FROM t1 JOIN t2 ON (t1.id = t2.id);
+\o
+\! sql/maskout.sh results/pg_hint_plan.tmpout
+
+\o results/pg_hint_plan.tmpout
 /*+ Rows(t1 t2 -99) */
 EXPLAIN SELECT * FROM t1 JOIN t2 ON (t1.id = t2.id);
+\o
+\! sql/maskout.sh results/pg_hint_plan.tmpout
+
+\o results/pg_hint_plan.tmpout
 /*+ Rows(t1 t2 *99) */
 EXPLAIN SELECT * FROM t1 JOIN t2 ON (t1.id = t2.id);
+\o
+\! sql/maskout.sh results/pg_hint_plan.tmpout
+
+\o results/pg_hint_plan.tmpout
 /*+ Rows(t1 t2 *0.01) */
 EXPLAIN SELECT * FROM t1 JOIN t2 ON (t1.id = t2.id);
+\o
+\! sql/maskout.sh results/pg_hint_plan.tmpout
+
+\o results/pg_hint_plan.tmpout
 /*+ Rows(t1 t2 #aa) */
-EXPLAIN SELECT * FROM t1 JOIN t2 ON (t1.id = t2.id);    -- ERROR
+EXPLAIN SELECT * FROM t1 JOIN t2 ON (t1.id = t2.id); -- ERROR
+\o
+\! sql/maskout.sh results/pg_hint_plan.tmpout
+
+\o results/pg_hint_plan.tmpout
 /*+ Rows(t1 t2 /99) */
-EXPLAIN SELECT * FROM t1 JOIN t2 ON (t1.id = t2.id);    -- ERROR
+EXPLAIN SELECT * FROM t1 JOIN t2 ON (t1.id = t2.id); -- ERROR
+\o
+\! sql/maskout.sh results/pg_hint_plan.tmpout
+
 -- round up to 1
+\o results/pg_hint_plan.tmpout
 /*+ Rows(t1 t2 -99999) */
 EXPLAIN SELECT * FROM t1 JOIN t2 ON (t1.id = t2.id);
+\o
+\! sql/maskout.sh results/pg_hint_plan.tmpout
+
 -- complex join tree
+\o results/pg_hint_plan.tmpout
 EXPLAIN SELECT * FROM t1 JOIN t2 ON (t1.id = t2.id) JOIN t3 ON (t3.id = t2.id);
+\o
+\! sql/maskout.sh results/pg_hint_plan.tmpout
+
+\o results/pg_hint_plan.tmpout
 /*+ Rows(t1 t2 #22) */
 EXPLAIN SELECT * FROM t1 JOIN t2 ON (t1.id = t2.id) JOIN t3 ON (t3.id = t2.id);
+\o
+\! sql/maskout.sh results/pg_hint_plan.tmpout
+
+\o results/pg_hint_plan.tmpout
 /*+ Rows(t1 t3 *10) */
 EXPLAIN SELECT * FROM t1 JOIN t2 ON (t1.id = t2.id) JOIN t3 ON (t3.id = t2.id);
+\o
+\! sql/maskout.sh results/pg_hint_plan.tmpout
+\! rm results/pg_hint_plan.tmpout
